summaryrefslogtreecommitdiff
path: root/pjsip/include
diff options
context:
space:
mode:
authorLiong Sauw Ming <ming@teluu.com>2013-03-06 05:55:09 +0000
committerLiong Sauw Ming <ming@teluu.com>2013-03-06 05:55:09 +0000
commit5087300ce2189c93021234508a2bb0cd497f1876 (patch)
tree0052ab3df4904f55d19a4d58ddea88c4a61e1b27 /pjsip/include
parent22da209226aac2c65f45900e55cf5f162cd311d4 (diff)
Fixed #1629: Add pjsua_call_set_hold2() API to allow update of Contact header
git-svn-id: http://svn.pjsip.org/repos/pjproject/trunk@4421 74dad513-b988-da41-8d7b-12977e46ad98
Diffstat (limited to 'pjsip/include')
-rw-r--r--pjsip/include/pjsua-lib/pjsua.h30
1 files changed, 24 insertions, 6 deletions
diff --git a/pjsip/include/pjsua-lib/pjsua.h b/pjsip/include/pjsua-lib/pjsua.h
index 5a4a0fa4..67fe430b 100644
--- a/pjsip/include/pjsua-lib/pjsua.h
+++ b/pjsip/include/pjsua-lib/pjsua.h
@@ -4009,12 +4009,12 @@ typedef enum pjsua_call_flag
/**
* Update the local invite session's contact with the contact URI from
* the account. This flag is only valid for #pjsua_call_reinvite() and
* #pjsua_call_update(). This flag is useful in IP address change
* situation, after the local account's Contact has been updated
* (typically with re-registration) use this flag to update the invite
* session with the new Contact and to inform this new Contact to the
* remote peer with the outgoing re-INVITE or UPDATE
*/
PJSUA_CALL_UPDATE_CONTACT = 2,
@@ -4474,6 +4474,24 @@ PJ_DECL(pj_status_t) pjsua_call_process_redirect(pjsua_call_id call_id,
PJ_DECL(pj_status_t) pjsua_call_set_hold(pjsua_call_id call_id,
const pjsua_msg_data *msg_data);
+/**
+ * Put the specified call on hold. This will send re-INVITE with the
+ * appropriate SDP to inform remote that the call is being put on hold.
+ * The final status of the request itself will be reported on the
+ * \a on_call_media_state() callback, which inform the application that
+ * the media state of the call has changed.
+ *
+ * @param call_id Call identification.
+ * @param options Bitmask of pjsua_call_flag constants. Currently, only
+ * the flag PJSUA_CALL_UPDATE_CONTACT can be used.
+ * @param msg_data Optional message components to be sent with
+ * the request.
+ *
+ * @return PJ_SUCCESS on success, or the appropriate error code.
+ */
+PJ_DECL(pj_status_t) pjsua_call_set_hold2(pjsua_call_id call_id,
+ unsigned options,
+ const pjsua_msg_data *msg_data);
/**
* Send re-INVITE to release hold.
@@ -4009,12 +4009,12 @@ typedef enum pjsua_call_flag
/**
* Update the local invite session's contact with the contact URI from
- * the account. This flag is only valid for #pjsua_call_reinvite() and
- * #pjsua_call_update(). This flag is useful in IP address change
- * situation, after the local account's Contact has been updated
- * (typically with re-registration) use this flag to update the invite
- * session with the new Contact and to inform this new Contact to the
- * remote peer with the outgoing re-INVITE or UPDATE
+ * the account. This flag is only valid for #pjsua_call_set_hold2(),
+ * #pjsua_call_reinvite() and #pjsua_call_update(). This flag is useful
+ * in IP address change situation, after the local account's Contact has
+ * been updated (typically with re-registration) use this flag to update
+ * the invite session with the new Contact and to inform this new Contact
+ * to the remote peer with the outgoing re-INVITE or UPDATE.
*/
PJSUA_CALL_UPDATE_CONTACT = 2,